@@ -114,13 +114,13 @@ extern SbkConverter **SbkPySide6_QtHelpTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 0, // const QList<QVersionNumber > &
-    SBK_QTHELP_QLIST_INT_IDX                                 = 1, // const QList<int > &
-    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 2, // const QList<QHelpLink > &
-    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 3, // const QMultiMap<QString,QUrl > &
+    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 0, // QList<QVersionNumber >
+    SBK_QTHELP_QLIST_INT_IDX                                 = 1, // QList<int >
+    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 2, // QList<QHelpLink >
+    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 3, // QMultiMap<QString,QUrl >
     SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 4, // QList<QAction* >
     SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 5, // QList<QHelpSearchQuery >
-    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 6, // const QList<QObject* > &
+    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 6, // QList<QObject* >
     SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 7, // QList<QByteArray >
     SBK_QTHELP_STD_PAIR_QSTRING_QSTRING_IDX                  = 8, // std::pair<QString,QString >
     SBK_QTHELP_QLIST_STD_PAIR_QSTRING_QSTRING_IDX            = 9, // QList<std::pair< QString,QString > >
@@ -130,7 +130,7 @@ enum : int {
     SBK_QTHELP_QLIST_QURL_IDX                                = 13, // QList<QUrl >
     SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 14, // QList<QStringList >
     SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 15, // QMap<int,QVariant >
-    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 16, // const QList<QPersistentModelIndex > &
+    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 16, // QList<QPersistentModelIndex >
     SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 17, // QHash<int,QByteArray >
     SBK_QTHELP_QLIST_QVARIANT_IDX                            = 18, // QList<QVariant >
     SBK_QTHELP_QLIST_QSTRING_IDX                             = 19, // QList<QString >
