@@ -68,6 +68,7 @@
 #include <QtOpenGL/qopenglfunctions_3_0.h>
 #include <QtOpenGL/qopenglfunctions_4_0_compatibility.h>
 #include <QtOpenGL/qopenglversionfunctions.h>
+#include <QtOpenGL/qopenglpaintdevice.h>
 #include <QtOpenGL/qopengltimerquery.h>
 #include <QtOpenGL/qopenglfunctions_1_4.h>
 #include <QtOpenGL/qopenglfunctions_4_4_compatibility.h>
@@ -155,42 +156,43 @@ enum : int {
     SBK_QOPENGLFUNCTIONS_4_4_CORE_IDX                        = 45,
     SBK_QOPENGLFUNCTIONS_4_5_COMPATIBILITY_IDX               = 46,
     SBK_QOPENGLFUNCTIONS_4_5_CORE_IDX                        = 47,
-    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 49,
-    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 51,
+    SBK_QOPENGLPAINTDEVICE_IDX                               = 49,
+    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 50,
+    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 52,
     SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX               = 5,
-    SBK_QOPENGLSHADER_IDX                                    = 50,
-    SBK_QOPENGLSHADERPROGRAM_IDX                             = 52,
-    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 67,
-    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 54,
-    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 62,
-    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 70,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 68,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 69,
-    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 58,
-    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 63,
-    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 64,
-    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 65,
-    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 66,
-    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 71,
-    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 57,
-    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 60,
+    SBK_QOPENGLSHADER_IDX                                    = 51,
+    SBK_QOPENGLSHADERPROGRAM_IDX                             = 53,
+    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 68,
+    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 55,
+    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 63,
+    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 71,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 69,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 70,
+    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 59,
+    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 64,
+    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 65,
+    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 66,
+    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 67,
+    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 72,
+    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 58,
+    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 61,
     SBK_QFLAGS_QOPENGLTEXTURE_FEATURE_IDX                    = 6,
-    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 59,
-    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 55,
-    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 56,
-    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 61,
-    SBK_QOPENGLTEXTURE_IDX                                   = 53,
-    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 73,
-    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 72,
-    SBK_QOPENGLTIMEMONITOR_IDX                               = 74,
-    SBK_QOPENGLTIMERQUERY_IDX                                = 75,
-    SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX                   = 76,
-    SBK_QOPENGLVERSIONPROFILE_IDX                            = 77,
-    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 78,
-    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 79,
-    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 81,
-    SBK_QOPENGLWINDOW_IDX                                    = 80,
-    SBK_QtOpenGL_IDX_COUNT                                   = 82
+    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 60,
+    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 56,
+    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 57,
+    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 62,
+    SBK_QOPENGLTEXTURE_IDX                                   = 54,
+    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 74,
+    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 73,
+    SBK_QOPENGLTIMEMONITOR_IDX                               = 75,
+    SBK_QOPENGLTIMERQUERY_IDX                                = 76,
+    SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX                   = 77,
+    SBK_QOPENGLVERSIONPROFILE_IDX                            = 78,
+    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 79,
+    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 80,
+    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 82,
+    SBK_QOPENGLWINDOW_IDX                                    = 81,
+    SBK_QtOpenGL_IDX_COUNT                                   = 83
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtOpenGLTypes;
@@ -272,6 +274,7 @@ template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_4_Compatibility >(
 template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_4_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_4_CORE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_5_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_5_COMPATIBILITY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_5_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_5_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLPaintDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLPAINTDEVICE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLPixelTransferOptions >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLShader::ShaderTypeBit >() { return SbkPySide6_QtOpenGLTypes[SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QOpenGLShader::ShaderTypeBit> >() { return SbkPySide6_QtOpenGLTypes[SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
