@@ -58,6 +58,7 @@
 #include <QtTest/qttestglobal.h>
 #include <QtTest/qtestkeyboard.h>
 #include <pysideqtesttouch.h>
+#include <QtTest/qsignalspy.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -79,13 +80,14 @@
 enum : int {
     SBK_QABSTRACTITEMMODELTESTER_FAILUREREPORTINGMODE_IDX    = 1,
     SBK_QABSTRACTITEMMODELTESTER_IDX                         = 0,
-    SBK_QTEST_TESTFAILMODE_IDX                               = 7,
-    SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 6,
-    SBK_QTEST_KEYACTION_IDX                                  = 3,
-    SBK_QTEST_MOUSEACTION_IDX                                = 4,
-    SBK_QtTestQTEST_IDX                                      = 2,
-    SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                  = 5,
-    SBK_QtTest_IDX_COUNT                                     = 8
+    SBK_QSIGNALSPY_IDX                                       = 2,
+    SBK_QTEST_TESTFAILMODE_IDX                               = 8,
+    SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 7,
+    SBK_QTEST_KEYACTION_IDX                                  = 4,
+    SBK_QTEST_MOUSEACTION_IDX                                = 5,
+    SBK_QtTestQTEST_IDX                                      = 3,
+    SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                  = 6,
+    SBK_QtTest_IDX_COUNT                                     = 9
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtTestTypes;
@@ -98,9 +100,9 @@ extern SbkConverter **SbkPySide6_QtTestTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 0, // QList<QObject* >
-    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 1, // QList<QByteArray >
-    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 2, // QList<QVariant >
+    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 0, // QList<QVariant >
+    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 1, // QList<QObject* >
+    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 2, // QList<QByteArray >
     SBK_QTTEST_QLIST_QSTRING_IDX                             = 3, // QList<QString >
     SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 4, // QMap<QString,QVariant >
     SBK_QtTest_CONVERTERS_IDX_COUNT                          = 5
@@ -115,6 +117,7 @@ QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAbstractItemModelTester::FailureReportingMode >() { return SbkPySide6_QtTestTypes[SBK_QABSTRACTITEMMODELTESTER_FAILUREREPORTINGMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAbstractItemModelTester >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtTestTypes[SBK_QABSTRACTITEMMODELTESTER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSignalSpy >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtTestTypes[SBK_QSIGNALSPY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTest::TestFailMode >() { return SbkPySide6_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide6_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QTest::KeyAction >() { return SbkPySide6_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
